# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.static_data.v1 import set_static_data_pb2 as systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2


class SetStaticDataServiceStub(object):
    """Called to set static data.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateStaticDataOtcStreaming = channel.unary_unary(
                '/systemathics.apis.services.static_data.v1.SetStaticDataService/CreateStaticDataOtcStreaming',
                request_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CreateStaticDataOtcStreamingRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.FromString,
                )
        self.GetStaticDataOtcStreaming = channel.unary_unary(
                '/systemathics.apis.services.static_data.v1.SetStaticDataService/GetStaticDataOtcStreaming',
                request_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.SingleStaticDataOtcStreamingRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.FromString,
                )
        self.GetAllStaticDataOtcStreaming = channel.unary_stream(
                '/systemathics.apis.services.static_data.v1.SetStaticDataService/GetAllStaticDataOtcStreaming',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.FromString,
                )
        self.UpdateStaticDataOtcStreaming = channel.unary_unary(
                '/systemathics.apis.services.static_data.v1.SetStaticDataService/UpdateStaticDataOtcStreaming',
                request_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.UpdateStaticDataOtcStreamingRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.FromString,
                )
        self.DeleteStaticDataOtcStreaming = channel.unary_unary(
                '/systemathics.apis.services.static_data.v1.SetStaticDataService/DeleteStaticDataOtcStreaming',
                request_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.SingleStaticDataOtcStreamingRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class SetStaticDataServiceServicer(object):
    """Called to set static data.
    """

    def CreateStaticDataOtcStreaming(self, request, context):
        """Creates Option Static data from OTC Streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStaticDataOtcStreaming(self, request, context):
        """Get Option Static data from OTC Streaming by Id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllStaticDataOtcStreaming(self, request, context):
        """Get all Option Static data from OTC Streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateStaticDataOtcStreaming(self, request, context):
        """Update Option Static data from OTC Streaming by Id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteStaticDataOtcStreaming(self, request, context):
        """Get Option Static data from OTC Streaming by Id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SetStaticDataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateStaticDataOtcStreaming': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStaticDataOtcStreaming,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CreateStaticDataOtcStreamingRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.SerializeToString,
            ),
            'GetStaticDataOtcStreaming': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStaticDataOtcStreaming,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.SingleStaticDataOtcStreamingRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.SerializeToString,
            ),
            'GetAllStaticDataOtcStreaming': grpc.unary_stream_rpc_method_handler(
                    servicer.GetAllStaticDataOtcStreaming,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.SerializeToString,
            ),
            'UpdateStaticDataOtcStreaming': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateStaticDataOtcStreaming,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.UpdateStaticDataOtcStreamingRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.SerializeToString,
            ),
            'DeleteStaticDataOtcStreaming': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteStaticDataOtcStreaming,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.SingleStaticDataOtcStreamingRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.static_data.v1.SetStaticDataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SetStaticDataService(object):
    """Called to set static data.
    """

    @staticmethod
    def CreateStaticDataOtcStreaming(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.static_data.v1.SetStaticDataService/CreateStaticDataOtcStreaming',
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.CreateStaticDataOtcStreamingRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStaticDataOtcStreaming(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.static_data.v1.SetStaticDataService/GetStaticDataOtcStreaming',
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.SingleStaticDataOtcStreamingRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllStaticDataOtcStreaming(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.static_data.v1.SetStaticDataService/GetAllStaticDataOtcStreaming',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateStaticDataOtcStreaming(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.static_data.v1.SetStaticDataService/UpdateStaticDataOtcStreaming',
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.UpdateStaticDataOtcStreamingRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.StaticDataOtcStreamingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteStaticDataOtcStreaming(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.static_data.v1.SetStaticDataService/DeleteStaticDataOtcStreaming',
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_set__static__data__pb2.SingleStaticDataOtcStreamingRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v2/get_intraday_scalar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@systemathics/apis/services/intraday/v2/get_intraday_scalar.proto\x12&systemathics.apis.services.intraday.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xba\x02\n\x15IntradayScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\x46\n\x08sampling\x18\x03 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12S\n\rdate_interval\x18\x04 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x1e\n\nadjustment\x18\x05 \x01(\x08R\nadjustment\"\xdb\x01\n\x1cIntradayScalarStreamResponse\x12X\n\x04info\x18\x01 \x01(\x0b\x32\x42.systemathics.apis.services.intraday.v2.IntradayScalarStreamFieldsH\x00R\x04info\x12V\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32@.systemathics.apis.services.intraday.v2.IntradayScalarStreamItemH\x00R\x04\x64\x61taB\t\n\x07payload\"4\n\x1aIntradayScalarStreamFields\x12\x16\n\x06\x66ields\x18\x01 \x03(\tR\x06\x66ields\"a\n\x18IntradayScalarStreamItem\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"\x8a\x01\n#IntradayScalarAssetProviderResponse\x12\x63\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32O.systemathics.apis.services.intraday.v2.IntradayScalarAssetProviderItemResponseR\x04\x64\x61ta\"\x91\x01\n\'IntradayScalarAssetProviderItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\"|\n\x1cIntradayScalarFieldsResponse\x12\\\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32H.systemathics.apis.services.intraday.v2.IntradayScalarFieldsItemResponseR\x04\x64\x61ta\"\xa2\x01\n IntradayScalarFieldsItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields2\xa4\x04\n\x15IntradayScalarService\x12\xc2\x01\n\x14IntradayScalarStream\x12=.systemathics.apis.services.intraday.v2.IntradayScalarRequest\x1a\x44.systemathics.apis.services.intraday.v2.IntradayScalarStreamResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v2/intraday_scalar_stream/0\x01\x12\x99\x01\n\x14IntradayScalarFields\x12\x16.google.protobuf.Empty\x1a\x44.systemathics.apis.services.intraday.v2.IntradayScalarFieldsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v2/intraday_scalar_fields/\x12\xa9\x01\n\x1bIntradayScalarAssetProvider\x12\x16.google.protobuf.Empty\x1aK.systemathics.apis.services.intraday.v2.IntradayScalarAssetProviderResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v2/intraday_scalar_provider/B\x81\x02\n*com.systemathics.apis.services.intraday.v2B\x16GetIntradayScalarProtoP\x01\xa2\x02\x04SASI\xaa\x02&Systemathics.Apis.Services.Intraday.V2\xca\x02&Systemathics\\Apis\\Services\\Intraday\\V2\xe2\x02\x32Systemathics\\Apis\\Services\\Intraday\\V2\\GPBMetadata\xea\x02*Systemathics::Apis::Services::Intraday::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday.v2.get_intraday_scalar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.systemathics.apis.services.intraday.v2B\026GetIntradayScalarProtoP\001\242\002\004SASI\252\002&Systemathics.Apis.Services.Intraday.V2\312\002&Systemathics\\Apis\\Services\\Intraday\\V2\342\0022Systemathics\\Apis\\Services\\Intraday\\V2\\GPBMetadata\352\002*Systemathics::Apis::Services::Intraday::V2'
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarStream']._options = None
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarStream']._serialized_options = b'\202\323\344\223\002\035\022\033/v2/intraday_scalar_stream/'
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarFields']._options = None
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarFields']._serialized_options = b'\202\323\344\223\002\035\022\033/v2/intraday_scalar_fields/'
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarAssetProvider']._options = None
  _globals['_INTRADAYSCALARSERVICE'].methods_by_name['IntradayScalarAssetProvider']._serialized_options = b'\202\323\344\223\002\037\022\035/v2/intraday_scalar_provider/'
  _globals['_INTRADAYSCALARREQUEST']._serialized_start=426
  _globals['_INTRADAYSCALARREQUEST']._serialized_end=740
  _globals['_INTRADAYSCALARSTREAMRESPONSE']._serialized_start=743
  _globals['_INTRADAYSCALARSTREAMRESPONSE']._serialized_end=962
  _globals['_INTRADAYSCALARSTREAMFIELDS']._serialized_start=964
  _globals['_INTRADAYSCALARSTREAMFIELDS']._serialized_end=1016
  _globals['_INTRADAYSCALARSTREAMITEM']._serialized_start=1018
  _globals['_INTRADAYSCALARSTREAMITEM']._serialized_end=1115
  _globals['_INTRADAYSCALARASSETPROVIDERRESPONSE']._serialized_start=1118
  _globals['_INTRADAYSCALARASSETPROVIDERRESPONSE']._serialized_end=1256
  _globals['_INTRADAYSCALARASSETPROVIDERITEMRESPONSE']._serialized_start=1259
  _globals['_INTRADAYSCALARASSETPROVIDERITEMRESPONSE']._serialized_end=1404
  _globals['_INTRADAYSCALARFIELDSRESPONSE']._serialized_start=1406
  _globals['_INTRADAYSCALARFIELDSRESPONSE']._serialized_end=1530
  _globals['_INTRADAYSCALARFIELDSITEMRESPONSE']._serialized_start=1533
  _globals['_INTRADAYSCALARFIELDSITEMRESPONSE']._serialized_end=1695
  _globals['_INTRADAYSCALARSERVICE']._serialized_start=1698
  _globals['_INTRADAYSCALARSERVICE']._serialized_end=2246
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v2/get_daily.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3systemathics/apis/services/daily/v2/get_daily.proto\x12#systemathics.apis.services.daily.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xc5\x01\n\x0c\x44\x61ilyRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12O\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\"\xc6\x01\n\x19\x44\x61ilyScalarStreamResponse\x12L\n\x04info\x18\x01 \x01(\x0b\x32\x36.systemathics.apis.services.daily.v2.DailyStreamFieldsH\x00R\x04info\x12P\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32:.systemathics.apis.services.daily.v2.DailyScalarStreamItemH\x00R\x04\x64\x61taB\t\n\x07payload\"\xc6\x01\n\x19\x44\x61ilyVectorStreamResponse\x12L\n\x04info\x18\x01 \x01(\x0b\x32\x36.systemathics.apis.services.daily.v2.DailyStreamFieldsH\x00R\x04info\x12P\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32:.systemathics.apis.services.daily.v2.DailyVectorStreamItemH\x00R\x04\x64\x61taB\t\n\x07payload\"+\n\x11\x44\x61ilyStreamFields\x12\x16\n\x06\x66ields\x18\x01 \x03(\tR\x06\x66ields\"R\n\x15\x44\x61ilyScalarStreamItem\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"d\n\x15\x44\x61ilyVectorStreamItem\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x12\n\x04\x64\x61ta\x18\x03 \x03(\x01R\x04\x64\x61ta\"y\n\x1b\x44\x61ilyAssetProvidersResponse\x12Z\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x42.systemathics.apis.services.daily.v2.DailyAssetProviderItemReponseR\x06\x61ssets\"\x89\x01\n\x1d\x44\x61ilyAssetProviderItemReponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1c\n\tproviders\x18\x02 \x03(\tR\tproviders\"\xc5\x01\n\x13\x44\x61ilyFieldsResponse\x12V\n\x07scalars\x18\x01 \x03(\x0b\x32<.systemathics.apis.services.daily.v2.DailyFieldsItemResponseR\x07scalars\x12V\n\x07vectors\x18\x02 \x03(\x0b\x32<.systemathics.apis.services.daily.v2.DailyFieldsItemResponseR\x07vectors\"\x99\x01\n\x17\x44\x61ilyFieldsItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields2\xe5\x04\n\x0c\x44\x61ilyService\x12\xa3\x01\n\x11\x44\x61ilyScalarStream\x12\x31.systemathics.apis.services.daily.v2.DailyRequest\x1a>.systemathics.apis.services.daily.v2.DailyScalarStreamResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v2/daily_scalar/0\x01\x12\xa3\x01\n\x11\x44\x61ilyVectorStream\x12\x31.systemathics.apis.services.daily.v2.DailyRequest\x1a>.systemathics.apis.services.daily.v2.DailyVectorStreamResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v2/daily_vector/0\x01\x12z\n\x0b\x44\x61ilyFields\x12\x16.google.protobuf.Empty\x1a\x38.systemathics.apis.services.daily.v2.DailyFieldsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v2/daily_fields/\x12\x8c\x01\n\x13\x44\x61ilyAssetProviders\x12\x16.google.protobuf.Empty\x1a@.systemathics.apis.services.daily.v2.DailyAssetProvidersResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v2/daily_provider/B\xe9\x01\n\'com.systemathics.apis.services.daily.v2B\rGetDailyProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V2\xca\x02#Systemathics\\Apis\\Services\\Daily\\V2\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v2.get_daily_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v2B\rGetDailyProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V2\312\002#Systemathics\\Apis\\Services\\Daily\\V2\342\002/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V2'
  _globals['_DAILYSERVICE'].methods_by_name['DailyScalarStream']._options = None
  _globals['_DAILYSERVICE'].methods_by_name['DailyScalarStream']._serialized_options = b'\202\323\344\223\002\023\022\021/v2/daily_scalar/'
  _globals['_DAILYSERVICE'].methods_by_name['DailyVectorStream']._options = None
  _globals['_DAILYSERVICE'].methods_by_name['DailyVectorStream']._serialized_options = b'\202\323\344\223\002\023\022\021/v2/daily_vector/'
  _globals['_DAILYSERVICE'].methods_by_name['DailyFields']._options = None
  _globals['_DAILYSERVICE'].methods_by_name['DailyFields']._serialized_options = b'\202\323\344\223\002\023\022\021/v2/daily_fields/'
  _globals['_DAILYSERVICE'].methods_by_name['DailyAssetProviders']._options = None
  _globals['_DAILYSERVICE'].methods_by_name['DailyAssetProviders']._serialized_options = b'\202\323\344\223\002\025\022\023/v2/daily_provider/'
  _globals['_DAILYREQUEST']._serialized_start=325
  _globals['_DAILYREQUEST']._serialized_end=522
  _globals['_DAILYSCALARSTREAMRESPONSE']._serialized_start=525
  _globals['_DAILYSCALARSTREAMRESPONSE']._serialized_end=723
  _globals['_DAILYVECTORSTREAMRESPONSE']._serialized_start=726
  _globals['_DAILYVECTORSTREAMRESPONSE']._serialized_end=924
  _globals['_DAILYSTREAMFIELDS']._serialized_start=926
  _globals['_DAILYSTREAMFIELDS']._serialized_end=969
  _globals['_DAILYSCALARSTREAMITEM']._serialized_start=971
  _globals['_DAILYSCALARSTREAMITEM']._serialized_end=1053
  _globals['_DAILYVECTORSTREAMITEM']._serialized_start=1055
  _globals['_DAILYVECTORSTREAMITEM']._serialized_end=1155
  _globals['_DAILYASSETPROVIDERSRESPONSE']._serialized_start=1157
  _globals['_DAILYASSETPROVIDERSRESPONSE']._serialized_end=1278
  _globals['_DAILYASSETPROVIDERITEMREPONSE']._serialized_start=1281
  _globals['_DAILYASSETPROVIDERITEMREPONSE']._serialized_end=1418
  _globals['_DAILYFIELDSRESPONSE']._serialized_start=1421
  _globals['_DAILYFIELDSRESPONSE']._serialized_end=1618
  _globals['_DAILYFIELDSITEMRESPONSE']._serialized_start=1621
  _globals['_DAILYFIELDSITEMRESPONSE']._serialized_end=1774
  _globals['_DAILYSERVICE']._serialized_start=1777
  _globals['_DAILYSERVICE']._serialized_end=2390
# @@protoc_insertion_point(module_scope)
